@@ -2,7 +2,9 @@ from functools import partial
 
 from confluent_kafka_helpers.exceptions import KafkaDeliveryError, KafkaError
 from confluent_kafka_helpers.metrics.callbacks import (
-    error_cb_metrics, on_delivery_cb_metrics, stats_cb_metrics
+    error_cb_metrics,
+    on_delivery_cb_metrics,
+    stats_cb_metrics,
 )
 
 
@@ -21,9 +23,7 @@ def default_error_cb(error, custom_cb=None, send_metrics=error_cb_metrics):
     raise KafkaError(str(error))
 
 
-def default_on_delivery_cb(
-    error, message, custom_cb=None, send_metrics=on_delivery_cb_metrics
-):
+def default_on_delivery_cb(error, message, custom_cb=None, send_metrics=on_delivery_cb_metrics):
     send_metrics(error, message)
     if custom_cb:
         custom_cb(error, message)
